Music Library alias Hector Barbossa
-----------------------------------

Api to manage my music library


File endpoints
==============

Manage the music file:

- add a file (specify a **type** from the list), ID3 tags MUST be set up
- remove a file
- change its **type**


Type endpoints
==============

Manage the types of the music (blues, rock, etc)

- add a type
- remove a type
- rename a type
- delete a type (no music file must be associated to this type when its deleted)


Sources
=======

Barbossa_ image

.. _Barbossa: https://www.pinterest.fr/pin/801148221193620417/
